package com.ztmap.project.zhny.lotusydfx.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.lotusydfx.mapper.TLotusYdfxMapper;
import com.ztmap.project.zhny.lotusydfx.domain.TLotusYdfx;
import com.ztmap.project.zhny.lotusydfx.service.ITLotusYdfxService;
import com.ztmap.common.utils.text.Convert;

/**
 * 用电分项统计Service业务层处理
 * 
 * @author ztmap
 * @date 2023-11-16
 */
@Service
public class TLotusYdfxServiceImpl implements ITLotusYdfxService 
{
    @Autowired
    private TLotusYdfxMapper tLotusYdfxMapper;

    /**
     * 查询用电分项统计
     * 
     * @param id 用电分项统计ID
     * @return 用电分项统计
     */
    @Override
    public TLotusYdfx selectTLotusYdfxById(Long id)
    {
        return tLotusYdfxMapper.selectTLotusYdfxById(id);
    }

    /**
     * 查询用电分项统计列表
     * 
     * @param tLotusYdfx 用电分项统计
     * @return 用电分项统计
     */
    @Override
    public List<TLotusYdfx> selectTLotusYdfxList(TLotusYdfx tLotusYdfx)
    {
        return tLotusYdfxMapper.selectTLotusYdfxList(tLotusYdfx);
    }

    /**
     * 新增用电分项统计
     * 
     * @param tLotusYdfx 用电分项统计
     * @return 结果
     */
    @Override
    public int insertTLotusYdfx(TLotusYdfx tLotusYdfx)
    {
        return tLotusYdfxMapper.insertTLotusYdfx(tLotusYdfx);
    }

    /**
     * 修改用电分项统计
     * 
     * @param tLotusYdfx 用电分项统计
     * @return 结果
     */
    @Override
    public int updateTLotusYdfx(TLotusYdfx tLotusYdfx)
    {
        return tLotusYdfxMapper.updateTLotusYdfx(tLotusYdfx);
    }

    /**
     * 删除用电分项统计对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTLotusYdfxByIds(String ids)
    {
        return tLotusYdfxMapper.deleteTLotusYdfxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用电分项统计信息
     * 
     * @param id 用电分项统计ID
     * @return 结果
     */
    @Override
    public int deleteTLotusYdfxById(Long id)
    {
        return tLotusYdfxMapper.deleteTLotusYdfxById(id);
    }
}
